@@ -19,18 +19,9 @@ class InMemoryLimiter(Limiter):
         :return: None
         :raise ConfigurationError: if storage is incorrectly configured (via self.init_app -> invoked through superclass)
         """
-        app: Optional[Flask] = kwargs.get("app")
-        if app:
-            self.logger = app.logger
-            for handler in app.logger.handlers:
-                self.logger.debug(f"Adding log handler to limiter: {str(handler)}")
-                self.logger.addHandler(handler)
-
         super().__init__(*args, **kwargs)
 
-    def init_app(
-        self, app: Flask
-    ) -> None:
+    def init_app(self, app: Flask) -> None:
         """
         patch self._check_storage into Flask-limiter, and ensure the storage backend is connected properly
         app config values.
@@ -41,6 +32,13 @@ class InMemoryLimiter(Limiter):
         super().init_app(app=app)
         self._check_storage()
 
+        # Attach any existing Flask log handlers
+        if app:
+            self.logger = app.logger
+            for handler in app.logger.handlers:
+                self.logger.debug(f"Adding log handler to limiter: {str(handler)}")
+                self.logger.addHandler(handler)
+
     def _check_storage(self) -> None:
         """
         Check the storage backed is connected correctly
@@ -49,4 +47,6 @@ class InMemoryLimiter(Limiter):
         """
         if not self._storage.check():
             self.logger.critical(f"Invalid storage configuration: {self._storage_uri}")
-            raise ConfigurationError("Invalid storage configuration")
+            raise ConfigurationError(
+                f"Invalid storage configuration: {self._storage_uri}"
+            )
